import { _ } from '@eslint-react/eff';
import { TSESTree } from '@typescript-eslint/types';
import { Scope } from '@typescript-eslint/scope-manager';
import { TSESTree as TSESTree$1 } from '@typescript-eslint/utils';
import * as VAR from '@eslint-react/var';

/**
 * Find the parent JSX attribute node of a node
 * @param node The node to find the parent attribute of
 * @param test The test to apply to the parent attribute
 * @returns The parent attribute node or undefined
 */
declare function findParentAttribute(node: TSESTree.Node, test?: (node: TSESTree.JSXAttribute) => boolean): TSESTree.JSXAttribute | _;

/**
 * Get the JSX attribute node with the given name
 * @param name The name of the attribute
 * @param attributes The attributes to search
 * @param initialScope The initial scope to use for variable resolution
 * @returns The JSX attribute node or undefined
 */
declare function getAttribute(name: string, attributes: (TSESTree$1.JSXAttribute | TSESTree$1.JSXSpreadAttribute)[], initialScope?: Scope): TSESTree$1.JSXAttribute | TSESTree$1.JSXSpreadAttribute | _;

/**
 * Get the stringified name of a JSX attribute
 * @param node The JSX attribute node
 * @returns The name of the attribute
 */
declare function getAttributeName(node: TSESTree$1.JSXAttribute): string;

/**
 * Get a StaticValue of the attribute value
 * @param node The JSX attribute node
 * @param name The name of the attribute
 * @param initialScope The initial scope to use
 * @returns The StaticValue of the attribute value
 */
declare function getAttributeValue(node: TSESTree$1.JSXAttribute | TSESTree$1.JSXSpreadAttribute, name: string, initialScope: Scope): Exclude<VAR.LazyValue, {
    kind: "lazy";
}>;

/**
 * Get the stringified name of a JSX element
 * @param node The JSX element node
 * @returns The name of the element
 */
declare function getElementType(node: TSESTree.JSXElement | TSESTree.JSXFragment): string;

declare function hasAttribute(name: string, attributes: TSESTree.JSXOpeningElement["attributes"], initialScope?: Scope): boolean;
declare function hasAnyAttribute(names: string[], attributes: TSESTree.JSXOpeningElement["attributes"], initialScope?: Scope): boolean;
declare function hasEveryAttribute(names: string[], attributes: TSESTree.JSXOpeningElement["attributes"], initialScope?: Scope): boolean;

type JSXDetectionHint = bigint;
declare const JSXDetectionHint: {
    readonly None: 0n;
    readonly SkipUndefined: bigint;
    readonly SkipNullLiteral: bigint;
    readonly SkipBooleanLiteral: bigint;
    readonly SkipStringLiteral: bigint;
    readonly SkipNumberLiteral: bigint;
    readonly SkipBigIntLiteral: bigint;
    readonly SkipEmptyArray: bigint;
    readonly SkipCreateElement: bigint;
    readonly StrictArray: bigint;
    readonly StrictLogical: bigint;
    readonly StrictConditional: bigint;
};
declare const DEFAULT_JSX_DETECTION_HINT: bigint;

/**
 * Heuristic decision to determine if a node is a JSX-like node.
 * @param code The sourceCode object
 * @param code.getScope The function to get the scope of a node
 * @param node The AST node to check
 * @param hint The `JSXDetectionHint` to use
 * @returns boolean
 */
declare function isJsxLike(code: {
    getScope: (node: TSESTree$1.Node) => Scope;
}, node: TSESTree$1.Node | _ | null, hint?: JSXDetectionHint): boolean;

declare function isJsxFragmentElement(node: TSESTree.Node): boolean;
declare function isJsxKeyedElement(node: TSESTree.Node, initialScope?: Scope): boolean;
declare function isJsxBuiltInElement(node: TSESTree.Node): boolean;
declare function isJsxUserDefinedElement(node: TSESTree.Node): boolean;

/**
 * Check if a node is a `JSXFragment` or a `Fragment` element
 * @param node The AST node to check
 * @returns `true` if the node is a `JSXFragment` or a `Fragment` element
 */
declare function isJsxFragment(node: TSESTree.Node | null | _): boolean;

/**
 * Check if a node is a `JSXText` or a `Literal` node
 * @param node The AST node to check
 * @returns `true` if the node is a `JSXText` or a `Literal` node
 */
declare function isJsxText(node: TSESTree.Node | null | _): node is TSESTree.JSXText | TSESTree.Literal;

/**
 * Get the stringified representation of a JSX node
 * @param node The JSX node
 * @returns The stringified representation
 */
declare function toString(node: TSESTree$1.JSXIdentifier | TSESTree$1.JSXMemberExpression | TSESTree$1.JSXNamespacedName | TSESTree$1.JSXOpeningElement | TSESTree$1.JSXClosingElement | TSESTree$1.JSXOpeningFragment | TSESTree$1.JSXClosingFragment | TSESTree$1.JSXText): string;

export { DEFAULT_JSX_DETECTION_HINT, JSXDetectionHint, findParentAttribute, getAttribute, getAttributeName, getAttributeValue, getElementType, hasAnyAttribute, hasAttribute, hasEveryAttribute, isJsxBuiltInElement, isJsxFragment, isJsxFragmentElement, isJsxKeyedElement, isJsxLike, isJsxText, isJsxUserDefinedElement, toString };
